@@ -1,7 +1,7 @@
 /*
  * lib/pg_statsinfo.sql.in
  *
- * Copyright (c) 2010-2012, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+ * Copyright (c) 2009-2016, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
  */
 
 -- Adjust this setting to control where the objects get created.
@@ -14,6 +14,16 @@ SET LOCAL client_min_messages = WARNING;
 CREATE SCHEMA statsinfo;
 REVOKE ALL ON SCHEMA statsinfo FROM PUBLIC;
 
+--
+-- statsinfo.array_agg()
+--
+CREATE AGGREGATE statsinfo.array_agg(anyelement)
+(
+	SFUNC=array_append,
+	STYPE=anyarray,
+	INITCOND='{}'
+);
+
 --
 -- statsinfo.sample()
 --
@@ -29,13 +39,21 @@ CREATE FUNCTION statsinfo.activity(
 	OUT idle_in_xact	float8,
 	OUT waiting			float8,
 	OUT running			float8,
+	OUT backends		integer)
+AS '$libdir/pg_statsinfo', 'statsinfo_activity'
+LANGUAGE C STRICT;
+
+--
+-- statsinfo.long_xact()
+--
+CREATE FUNCTION statsinfo.long_xact(
 	OUT client			text,
 	OUT pid				integer,
 	OUT start			timestamptz,
 	OUT duration		float8,
-	OUT query			text
-)
-AS '$libdir/pg_statsinfo', 'statsinfo_activity'
+	OUT query			text)
+RETURNS SETOF record
+AS '$libdir/pg_statsinfo', 'statsinfo_long_xact'
 LANGUAGE C STRICT;
 
 --
@@ -74,6 +92,20 @@ LANGUAGE C STRICT;
 CREATE VIEW statsinfo.tablespaces AS
 	SELECT * FROM statsinfo.tablespaces();
 
+--
+-- statsinfo.start()
+--
+CREATE FUNCTION statsinfo.start(timeout integer) RETURNS void
+AS '$libdir/pg_statsinfo', 'statsinfo_start'
+LANGUAGE C;
+
+--
+-- statsinfo.stop()
+--
+CREATE FUNCTION statsinfo.stop(timeout integer) RETURNS void
+AS '$libdir/pg_statsinfo', 'statsinfo_stop'
+LANGUAGE C;
+
 --
 -- statsinfo.restart()
 --
@@ -130,19 +162,8 @@ LANGUAGE C STRICT;
 --
 -- statsinfo.devicestats()
 --
-CREATE TYPE statsinfo.devicestats_type AS
-(
-	device_name			text,
-	device_readsector	bigint,
-	device_readtime		bigint,
-	device_writesector	bigint,
-	device_writetime	bigint,
-	device_iototaltime	bigint
-);
-
 CREATE FUNCTION statsinfo.devicestats
 (
-	IN  prev_devicestats	statsinfo.devicestats_type[],
 	OUT device_major		text,
 	OUT device_minor		text,
 	OUT device_name			text,
@@ -151,7 +172,9 @@ CREATE FUNCTION statsinfo.devicestats
 	OUT device_writesector	bigint,
 	OUT device_writetime	bigint,
 	OUT device_ioqueue		bigint,
-	OUT device_iototaltime	bigint,
+	OUT device_iototaltime	bigint,	
+	OUT device_rsps_max		float8,
+	OUT device_wsps_max		float8,
 	OUT overflow_drs		smallint,
 	OUT overflow_drt		smallint,
 	OUT overflow_dws		smallint,
@@ -163,28 +186,6 @@ RETURNS SETOF record
 AS '$libdir/pg_statsinfo', 'statsinfo_devicestats'
 LANGUAGE C;
 
-CREATE FUNCTION statsinfo.devicestats
-(
-	OUT device_major		text,
-	OUT device_minor		text,
-	OUT device_name			text,
-	OUT device_readsector	bigint,
-	OUT device_readtime		bigint,
-	OUT device_writesector	bigint,
-	OUT device_writetime	bigint,
-	OUT device_ioqueue		bigint,
-	OUT device_iototaltime	bigint,
-	OUT overflow_drs		smallint,
-	OUT overflow_drt		smallint,
-	OUT overflow_dws		smallint,
-	OUT overflow_dwt		smallint,
-	OUT overflow_dit		smallint,
-	OUT device_tblspaces	name[]
-)
-RETURNS SETOF record
-AS '$libdir/pg_statsinfo', 'statsinfo_devicestats_noarg'
-LANGUAGE C;
-
 --
 -- statsinfo.loadavg()
 --
